@@ -6,32 +6,30 @@
 ( cd opt/kde/share/doc/HTML/de/kdm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kig ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/juk ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/ktuberling ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/ktuberling ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/amor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/karm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kate ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kdat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kdat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kget ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kget ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kgpg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kgpg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kmag ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmid ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmix ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kolf ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kolf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kpat ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kpat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kodo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kodo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/korn ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kppp ; rm -rf common )
@@ -116,24 +114,24 @@
 ( cd opt/kde/share/doc/HTML/de/kwin4 ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kgoldrunner ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klipper ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kmousetool ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kontact ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kontact ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/konsolekalendar ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpackage ; rm -rf common )
@@ -164,6 +162,8 @@
 ( cd opt/kde/share/doc/HTML/de/kwallet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmenuedit ; rm -rf common )
@@ -402,6 +402,8 @@
 ( cd opt/kde/share/doc/HTML/de/klines ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmines ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kmouth ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmplot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/knotes ; rm -rf common )
@@ -456,12 +458,16 @@
 ( cd opt/kde/share/doc/HTML/de/kghostview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kleopatra ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kenolaba ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kworldclock ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/KRegExpEditor ; rm -rf common )
@@ -516,5 +522,3 @@
 ( cd opt/kde/share/doc/HTML/de/konqueror ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/korganizer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/atlantik ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/atlantik ; ln -sf /opt/kde/share/doc/HTML/de/common common )
